<CsoundSynthesizer>

<CsOptions>
-odac
</CsOptions>

<CsInstruments>

/*
Marching To The Sirens Of War
Lee Zakian
2/28/05

========================================================
INSTRUMENTS	SIGNAL FLOW	
	
			iout			Mixer
1	Gliss 1		1			100	Channel 1/Out: L-R
2	Gliss 2		2			100	Channel 2/Out: L-R
3	Gliss 3		3			100	Channel 3/Out: L-R
			
	2 Part Canon		EQ	Reverb	Mixer	PANNED OUTPUT
4	Flute 1		4	92	97-L	100	Channel 4/Out: L-R
5	Flute 2		5	93	97-R	100	Channel 5/Out: L-R
	
6	Bass		6	94	98	100	Channel 6/Out: L-R
========================================================
*/

	sr = 44100
	kr = 4410
	ksmps = 10
	nchnls = 2
	zakinit	 	20, 20

	instr 1
;==========
;|||||||||| 	Gliss 1
;==========
;Pitch/Amplitude
kglis	expseg	220, p3/5, 440, p3/5, 880, p3/5, 110, p3/5, 440, p3/5, 220
kamp  	linseg	100, p3/5, 200, p3/5, 500, p3/5, 200, p3/5, 100, p3/5, 50
k1	linen	kamp, p10, p3, p11	;attack release envelope
k2	expon	p8, p3, p9		;harmonic envelope

;Reverb
irvbtime	=	p4
iwet		=	p5
idry		=	1-p5
ihfroll		=	p6	;low pass filter: high frequency rolloff
ihfdiff		=	p7	;high frequency diffusion
iout		=	1	;Mixer channel, with Gliss 2

a1	oscili	k1, (k2+1)*kglis, 1	;table 1
arevL	nreverb	(a1*1.5)*iwet, p4, p7
aout	tone	arevL, p6

;Pan
kpan	linseg	1, p3/5, .7, p3/5, .3, p3/5, 0, p3/5, .3, p3/5, .9
kpanL	=	kpan
kpanR	=	1-kpan
	zawm		aout*(kpanL+kpanR), iout
	endin

	instr 2
;==========
;|||||||||| 	Gliss 2
;==========
;Pitch/Amplitude
kglis2	expseg	110, p3/9, 440, p3/9, 220, p3/9, 880, p3/9, 220, p3/9, 440, p3/9, 110, p3/9, 220, p3/9, 440, p3/9, 55
kamp  	linseg	100, p3/5, 200, p3/5, 500, p3/5, 200, p3/5, 100, p3/5, 50
k1	linen	kamp, p10, p3, p11	;attack release envelope
k2	expon	p8, p3, p9		;harmonic envelope

;Reverb
irvbtime	=	p4
iwet		=	p5
idry		=	1-p5
ihfroll		=	p6	;low pass filter: high frequency rolloff
ihfdiff		=	p7	;high frequency diffusion
iout		=	2	;Mixer channel, with Gliss 1

a2	oscili	k1, (k2+1)*kglis2, 2	;table 2
arevR	nreverb	(a2*1.5)*iwet, p4, p7
aout	tone	arevR, p6

;Pan
kpan	linseg	0, p3/5, .2, p3/5, .6, p3/5, 1, p3/5, .5, p3/5, .2
kpanL	=	kpan
kpanR	=	1-kpan
	zawm		aout*(kpanL+kpanR), iout
	endin

	instr 3
;==========
;|||||||||| 	Gliss 3
;==========
;Pitch/Amplitude
kglis3	linseg	50, p3/4, 200, p3/4, 100, p3/4, 300, p3/4, 50
kglis4	linseg	60, p3/6, 300, p3/6, 500, p3/6, 700, p3/6, 300, p3/6, 100, p3/6, 60
kamp  	linseg	500, p3/3, 200, p3/3, 500, p3/3, 100
k1	linen	kamp, p10, p3, p11	;attack release envelope
k2	expon	p8, p3, p9		;harmonic envelope

;Reverb
irvbtime	=	p4
iwet		=	p5
idry		=	1-p5
ihfroll		=	p6	;low pass filter: high frequency rolloff
ihfdiff		=	p7	;high frequency diffusion
iout		=	3	;to Mixer channel

a1	oscili	k1, (k2+1)*kglis3, 1, 3	;table 3
a2	oscili	k1, (k2+1)*kglis4, 1, 4	;table 4
arev1	nreverb	(a1*1.5)*iwet, p4, p7
arev2	nreverb	(a2*1.5)*iwet, p4, p7
aout1	tone	arev1, p6
aout2	tone	arev2, p6
	zawm	aout1+aout2, iout
	endin

	instr 4
;==========
;|||||||||| 	Flute 1		Range of Flute		B3-D7	(7.11-11.02)
;========== 	Range of Piece		D4-C6	(8.02-10.00)
idur    	=       	abs(p3)	;absolute duration value
ipch1   =       	cpspch(p6)
ipch2   =       	cpspch(p5) 
kpch    	=       	ipch2
iport   	=       	(p6=0 ? 0.003 : 0.5)
	    	;portamento:glissando from P6 pitch, minimal pitch ramp when P6=0
iamp    	=       	p4	;tied note starts at amp ramp
;=====================
;VARIABLE TABLES
;=====================
iatkfn	=	26	;attack	
idecfn	=	28	;decay
icutfn	=	31	;high partials trim
ibrthfn	=	29	;breath
ivdfn	=	30	;vibrato depth
;=====================
;ATTACK
;=====================   
ioctat	=	octpch(p5)
iminat	=	octpch(10.00)
imaxat	=	octpch(8.02)
irngat	=	iminat-imaxat
indxat	=	(ioctat-iminat)/irngat
iatt	tablei	indxat, iatkfn, 1
iatt	=	(p3<0.4 ? (p3*0.1) : iatt)
;=====================
;DECAY
;=====================
ioctdc	=	octpch(p5)
imndc	=	octpch(10.00)
imxdc	=	octpch(8.02)
irngdc	=	imndc-imxdc
indxd	=	idur
indxdc	=	indxd+(ioctdc-imndc)/irngdc
idec	tablei	indxdc, idecfn, 1
idec	=	(p3<0.4 ? (p3*0.1) : idec)
;=====================
;PEAK/SWELL
;=====================
iout	=	4	;to EQ Instr 92
irise   	=       	idur*p8  ;0.1 = decresendo, 0.9 = crescendo, 0.5 = peak in middle
i1      	=       	-1         	;tied note phase
i2      	=       	-1          ;vibrato phase
kdclk	linseg  	0, .002, 1, p3-.004, 1, .002, 0	;declick envelope
;=====================
;AMPLITUDE RAMP 
;=====================
amp     		linseg  	iamp, iatt, iamp, idur-0.7, iamp, idec, iamp
;=====================
;PITCH
;=====================
pitch:
kpramp	linseg  	ipch1, iport, ipch2, idur-iport, ipch2
kpch  	=       	kpramp
;=====================
;EXPRESSION 
;rise/fall, vibrato
;=====================
expr:
irise	=	(p8 >0 ? irise : iatt)
ifall	=	idur-irise
p7	=	((p7+p4) >0 ? p7 : -p4)
aslur   	linseg  	0, irise, p7, ifall, 0	;make vibrato
;=====================
;VIBRATO DEPTH
;=====================
ioctvd	=	octpch(p5)
iminvd	=	octpch(8.02)
imaxvd	=	octpch(10.00)
irngvd	=	iminvd-imaxvd
indxvd	=	(ioctvd-iminvd)/irngvd
ivibd	tablei	indxvd, ivdfn, 1
avib	oscili	ivibd*2.5, p9, 25, 0.25	;vibrato depth, speed, table, phase
avib	=	avib+0.5
;=====================
;BREATH
;=====================
ioctbr	=	octpch(p5)
imnbr	=	octpch(8.02)
imxbr	=	octpch(10.00)
irngbr	=	imnbr-imxbr
indxbr	=	(ioctbr-imnbr)/irngbr
ibrth	tablei		indxbr, ibrthfn, 1
kenv1	linseg		0, .06, .5, .2, .9, p3-.16, .5, .02, 0
kenv2	linseg		0, .001, .1, p3-.002, .1, .001, 0
aflow	pinkish	kenv1*(p7*.02)
asum	=	(ibrth+aflow+kenv1)*avib
aslur   	=       	(aslur*avib)+asum
;=====================
;HIGH PARTIAL TRIM
;===================== 
ioct	=	octpch(p5)
imin	=	octpch(8.02)
imax	=	octpch(10.00)
irange	=	imin-imax
index	=	(ioct-imin)/irange
icut	tablei	index, icutfn, 1
;=====================
;PLAY 
;output to EQ instr 92
;=====================
play:					  ;waveform tables
aflu1	oscil3  		(amp+aslur), kpch, 5, i1		
aflu2	oscil3  		(amp+aslur), kpch, 6, i1
aflu3	oscil3  		(amp+aslur), kpch, 7, i1
aflu4	oscil3  		(amp+aslur), kpch, 8, i1
aflu5	oscil3  		(amp+aslur), kpch, 9, i1
aflu6	oscil3  		(amp+aslur), kpch, 10, i1
asig   	butterlp 	(aflu1+aflu2+aflu3+aflu4+aflu5+aflu6), icut, 1
	zawm		(asig*2.5)+asum*kenv2*kdclk, iout

	endin

	instr 5
;==========
;|||||||||| 	Flute 2		Range of Flute		B3-D7	(7.11-11.02)
;========== 	Range of Piece		????
idur    	=       	abs(p3)	;absolute duration value
ipch1   =       	cpspch(p6)
ipch2   =       	cpspch(p5)
kpch    	=       	ipch2
iport   	=       	(p6=0 ? 0.003 : 0.5)
	    	;portamento:glissando from P6 pitch, minimal pitch ramp when P6=0
iamp    	=       	p4	;tied note starts at amp ramp
;=====================
;VARIABLE TABLES
;=====================
iatkfn	=	26	;attack	
idecfn	=	28	;decay
icutfn	=	31	;high partials trim
ibrthfn	=	29	;breath
ivdfn	=	30	;vibrato depth
;=====================
;ATTACK
;=====================   
ioctat	=	octpch(p5)
iminat	=	octpch(10.00)
imaxat	=	octpch(8.02)
irngat	=	iminat-imaxat
indxat	=	(ioctat-iminat)/irngat
iatt	tablei	indxat, iatkfn, 1
iatt	=	(p3<0.4 ? (p3*0.1) : iatt)
;=====================
;DECAY
;=====================
ioctdc	=	octpch(p5)
imndc	=	octpch(10.00)
imxdc	=	octpch(8.02)
irngdc	=	imndc-imxdc
indxd	=	idur
indxdc	=	indxd+(ioctdc-imndc)/irngdc
idec	tablei	indxdc, idecfn, 1
idec	=	(p3<0.4 ? (p3*0.1) : idec)
;=====================
;PEAK/SWELL
;=====================
iout	=	5	;to EQ Instr 92
irise   	=       	idur*p8  ;0.1 = decresendo, 0.9 = crescendo, 0.5 = peak in middle
i1      	=       	-1         	;tied note phase
i2      	=       	-1          ;vibrato phase
kdclk	linseg  	0, .002, 1, p3-.004, 1, .002, 0	;declick envelope
;=====================
;AMPLITUDE RAMP 
;=====================
amp     		linseg  	iamp, iatt, iamp, idur-0.7, iamp, idec, iamp
;=====================
;PITCH
;=====================
pitch:
kpramp	linseg  	ipch1, iport, ipch2, idur-iport, ipch2
kpch  	=       	kpramp
;=====================
;EXPRESSION 
;rise/fall, vibrato
;=====================
expr:
irise	=	(p8 >0 ? irise : iatt)
ifall	=	idur-irise
p7	=	((p7+p4) >0 ? p7 : -p4)
aslur   	linseg  	0, irise, p7, ifall, 0	;make vibrato
;=====================
;VIBRATO DEPTH
;=====================
ioctvd	=	octpch(p5)
iminvd	=	octpch(8.02)
imaxvd	=	octpch(10.00)
irngvd	=	iminvd-imaxvd
indxvd	=	(ioctvd-iminvd)/irngvd
ivibd	tablei	indxvd, ivdfn, 1
avib	oscili	ivibd*2.5, p9, 25, 0.25	;vibrato depth, speed, table, phase
avib	=	avib+0.5
;=====================
;BREATH
;=====================
ioctbr	=	octpch(p5)
imnbr	=	octpch(8.02)
imxbr	=	octpch(10.00)
irngbr	=	imnbr-imxbr
indxbr	=	(ioctbr-imnbr)/irngbr
ibrth	tablei		indxbr, ibrthfn, 1
kenv1	linseg		0, .06, .5, .2, .9, p3-.16, .5, .02, 0
kenv2	linseg		0, .001, .1, p3-.002, .1, .001, 0
aflow	pinkish	kenv1*(p7*.02)
asum	=	(ibrth+aflow+kenv1)*avib
aslur   	=       	(aslur*avib)+asum
;=====================
;HIGH PARTIAL TRIM
;===================== 
ioct	=	octpch(p5)
imin	=	octpch(8.02)
imax	=	octpch(10.00)
irange	=	imin-imax
index	=	(ioct-imin)/irange
icut	tablei	index, icutfn, 1
;=====================
;PLAY 
;output to EQ instr 92
;=====================
play:					  ;waveform tables
aflu1	oscil3  		(amp+aslur), kpch, 5, i1		
aflu2	oscil3  		(amp+aslur), kpch, 6, i1
aflu3	oscil3  		(amp+aslur), kpch, 7, i1
aflu4	oscil3  		(amp+aslur), kpch, 8, i1
aflu5	oscil3  		(amp+aslur), kpch, 9, i1
aflu6	oscil3  		(amp+aslur), kpch, 10, i1
asig   	butterlp 	(aflu1+aflu2+aflu3+aflu4+aflu5+aflu6), icut, 1
	zawm		(asig*2.5)+asum*kenv2*kdclk, iout
	endin

	instr 6
;==========
;|||||||||| 	Bass			Total Range		G1-E4	(5.07-9.04)
;========== 		Range of Piece		G2-A3	(6.07-7.09)

idur    	=       	abs(p3)	;absolute duration value
ipch	=       	cpspch(p5) 
kpch    	=       	ipch
iamp    	=       	p4	;tied note starts at amp ramp
;=====================
;VARIABLE TABLES
;=====================
iatkfn	=	26	;attack	
idecfn	=	28	;decay
icutfn	=	32	;high partials trim
ivdfn	=	30	;vibrato depth
;=====================
;ATTACK
;=====================   
ioctat	=	octpch(p5)
iminat	=	octpch(7.09)
imaxat	=	octpch(6.07)
irngat	=	iminat-imaxat
indxat	=	(ioctat-iminat)/irngat
iatt	tablei	indxat, iatkfn, 1
;=====================
;DECAY
;=====================
ioctdc	=	octpch(p5)
imndc	=	octpch(6.07)
imxdc	=	octpch(7.09)
irngdc	=	imndc-imxdc
indxd	=	idur
indxdc	=	indxd+(ioctdc-imndc)/irngdc
idec	tablei	indxdc, idecfn, 1
;=====================
;PEAK/SWELL
;=====================
iout	=	6	;to EQ Instr 95
irise   	=       	idur*p7  ;0.1 = decresendo, 0.9 = crescendo, 0.5 = peak in middle
i1      	=       	-1         	;tied note phase
i2      	=       	-1          	;vibrato phase
kdclk	linseg  	0, .002, 1, p3-.004, 1, .002, 0	;declick envelope
;=====================
;AMPLITUDE RAMP 
;=====================
kamp   	linseg  	iamp, iatt, iamp, idur-0.6, iamp, idec, iamp
;=====================
;EXPRESSION 
;rise/fall, vibrato
;=====================
expr:
irise	=	(p7 >0 ? irise : iatt)
ifall	=	idur-irise
p6	=	((p6+p4) >0 ? p6 : -p4)
kslur   	linseg  	0, irise, p6, ifall, 0	;make vibrato
;=====================
;VIBRATO DEPTH
;=====================
ioctvd	=	octpch(p5)
iminvd	=	octpch(6.07)
imaxvd	=	octpch(7.09)
irngvd	=	iminvd-imaxvd
indxvd	=	(ioctvd-iminvd)/irngvd
ivibd	tablei	indxvd, ivdfn, 1
kvib	oscili	ivibd*3.5, p8, 25, 0.25	;vibrato depth, speed, table, phase
kvib	=	kvib+0.5
kslur	=	kslur*kvib
;=====================
;HIGH PARTIAL TRIM
;===================== 
ioct	=	octpch(p5)
imin	=	octpch(6.07)
imax	=	octpch(7.09)
irange	=	imin-imax
index	=	(ioct-imin)/irange
icut	tablei	index, icutfn, 1
;=====================
;PLAY 
;output to EQ instr
;=====================
play:			;waveform tables
abs1	pluck  		kamp+kslur, kpch, ipch, 19, 3, 0		
abs2	pluck  		kamp+kslur, kpch, ipch, 20, 3, 0
abs3	pluck  		kamp+kslur, kpch, ipch, 21, 3, 0
abs4	pluck  		kamp+kslur, kpch, ipch, 22, 3, 0
abs5	pluck  		kamp+kslur, kpch, ipch, 23, 3, 0
abs6	pluck  		kamp+kslur, kpch, ipch, 24, 3, 0
asig   	butterlp 	(abs1+abs2+abs3+abs4+abs5+abs6), icut, 1	;add tables, trim high partials
	zawm		(asig*1.5)*kdclk, iout
	endin
	
	instr   92
;==========
;|||||||||| 	EQ 1		Flute 1
;========== 
ilg1 		=	p4	;low gain1
ilg2 		=	p5	;low gain2
img 		=      	p6	;mid gain      
ihg1 		=       	p7	;high gain1
ihg2		=	p8	;high gain2
	
iin		=	p9
iout		=	p10	;to Reverb Instr 97 Left

ilc1		table	0, 33
ilc2		table	1, 33
ihc1		table	2, 33
ihc2		table	3, 33

asig		zar		iin
alsig1		butterlp	asig, ilc1		;low cut 1
alsig2		butterlp 	asig, ilc2	      	;low cut 2
atemp	 	butterhp 	asig, ilg2-ilc2/4		;mid range temp
amsig 		butterlp 	atemp, ihg1+ihc1/4	;mid cut
ahsig1 		butterhp 	asig, ihc1	       	;high cut 1
ahsig2 		butterhp 	asig, ihc2		;high cut 2

				;mac opcode multiplies & accumulates signals
aout		mac		ilg1, alsig1, ilg2, alsig2, img, amsig, ihg1, ahsig1, ihg2, ahsig2	
		zawm		aout, iout
		endin

	instr   93
;==========
;|||||||||| 	EQ 2		Flute 2
;========== 
ilg1 		=	p4	;low gain1
ilg2 		=	p5	;low gain2
img 		=      	p6	;mid gain      
ihg1 		=       	p7	;high gain1
ihg2		=	p8	;high gain2
	
iin		=	p9	
iout		=	p10	;to Reverb Instr 97 Right

ilc1		table	0, 34
ilc2		table	1, 34
ihc1		table	2, 34
ihc2		table	3, 34

asig		zar		iin
alsig1		butterlp	asig, ilc1		;low cut 1
alsig2		butterlp 	asig, ilc2	      	;low cut 2
atemp	 	butterhp 	asig, ilg2-ilc2/4		;mid range temp
amsig 		butterlp 	atemp, ihg1+ihc1/4	;mid cut
ahsig1 		butterhp 	asig, ihc1	       	;high cut 1
ahsig2 		butterhp 	asig, ihc2		;high cut 2

				;mac opcode multiplies & accumulates signals
aout		mac		ilg1, alsig1, ilg2, alsig2, img, amsig, ihg1, ahsig1, ihg2, ahsig2	
		zawm		aout, iout
		endin

	instr   94
;==========
;|||||||||| 	EQ 4		Bass
;========== 	

ilg1 		=	p4	;low gain1
ilg2 		=	p5	;low gain2
img 		=      	p6	;mid gain      
ihg1 		=       	p7	;high gain1
ihg2		=	p8	;high gain2
	
iin		=	p9
iout		=	p10	;to Reverb Instr 98 Right

ilc1		table	0, 35	
ilc2		table	1, 35	
ihc1		table	2, 35	
ihc2		table	3, 35

asig		zar		iin
alsig1		butterlp	asig, ilc1		;low cut 1
alsig2		butterlp 	asig, ilc2	      	;low cut 2
atemp	 	butterhp 	asig, ilg2-ilc2/4		;mid range temp
amsig 		butterlp 	atemp, ihg1+ihc1/4	;mid cut
ahsig1 		butterhp 	asig, ihc1	       	;high cut 1
ahsig2 		butterhp 	asig, ihc2		;high cut 2

				;mac opcode multiplies & accumulates signals
aout		mac		ilg1, alsig1, ilg2, alsig2, img, amsig, ihg1, ahsig1, ihg2, ahsig2	
		zawm		aout, iout
		endin

	instr 97	
;==========
;|||||||||| 	REVERB 1	Flute 1	Left
;==========	Flute 2	Right
iinL		=	p4
iinR		=	p5
ioutL		=	p6	;to Mixer Instr 100 Channel 3
ioutR		=	p7	;to Mixer Instr 100 Channel 4

irvbtimeL	=	p8
irvbtimeR	=	p9
iwetL		=	p10
idryL		=	1-p10
iwetR		=	p11
idryR		=	1-p11
ihfrollL	=	p12	;low pass filter: high frequency rolloff
ihfrollR	=	p13
ihfdiffL	=	p14	;high frequency diffusion
ihfdiffR	=	p15
kdclk		linseg  	0, .2, 1, p3-.4, 1, .2, 0	;declick envelope

asigL		zar	iinL	;Flute 1
asigR		zar	iinR	;Flute 2

aoutrevL	nreverb	asigL*iwetL, p8, p14
aoutrevR	nreverb	asigR*iwetR, p9, p15
aoutL		tone	aoutrevL, p12
aoutR		tone	aoutrevR, p13
		zawm	(aoutL+(asigL*idryL))*kdclk, ioutL
		zawm	(aoutR+(asigR*idryR))*kdclk, ioutR
		endin

	instr 98	
;==========
;|||||||||| 	REVERB 2	Bass
;==========	
iin		=	p4
iout		=	p5	;to Mixer Instr 100 Channel 6
irvbtime	=	p6
iwet		=	p7
idry		=	1-p7
ihfroll		=	p8	;low pass filter: high frequency rolloff
ihfdiff		=	p9	;high frequency diffusion
kdclk		linseg  	0, .2, 1, p3-.4, 1, .2, 0	;declick envelope
asig		zar	iin	;Bass
aoutrev	nreverb	asig*iwet, p6, p9
aout		tone	aoutrev, p8
		zawm	(aout+(asig*idry))*kdclk, iout
		endin

	instr 100
;==========
;|||||||||| MIXER		6 in, 2 out
;==========

;|||||||||| Gliss Instruments
;=====CHANNEL 1	=================================
a1		zar	p4		;IN	Gliss 1			 |
igLR1		init	p5		;GAIN				 |
;=====CHANNEL 2	=================================
a2		zar	p6		;IN	Gliss 2			 |
igLR2		init	p7		;GAIN				 |
;=====CHANNEL 3	=================================
a3		zar	p8		;IN	Gliss 3			 |
igLR3		init	p9		;GAIN				 |
;=================================================

;|||||||||| 2 Part Canon
;=====CHANNEL 4	=================================
a4		zar	p10		;IN	Flute 1			 |
igL4		init	p11*p12		;GAIN			 |
igR4		init	p11*(1-p12)	;PAN	1=left, 0=right		 |
;=====CHANNEL 5	=================================
a5		zar	p13		;IN	Flute 2			 |
igL5		init	p14*p15	;GAIN				 |
igR5		init	p14*(1-p15)	;PAN	1=left, 0=right		 |
;=================================================

;|||||||||| Bass
;=====CHANNEL 6	=================================
a6		zar	p16		;IN	Bass			 |
igL6		init	p17*p18	;GAIN				 |
igR6		init	p17*(1-p18)	;PAN	1=left, 0=right		 |
;=================================================

			;mac opcode multiplies & accumulates signals
aoutL		mac	igLR1, a1, igLR2, a2, igLR3, a3, igL4, a4, igL5, a5, igL6, a6 
aoutR		mac	igLR1, a1, igLR2, a2, igLR3, a3, igR4, a4, igR5, a5, igR6, a6 
		outs	aoutL, aoutR
		zacl	0, 20	;clear audio channels 0 to 20
		endin

</CsInstruments>

<CsScore>

/*
Marching To The Sirens Of War
Lee Zakian
2/28/05

======================================================
*****P fields for Flutes and Bass						|
Negative P3 values indicate slurs						|
P4=arbitrary starting amplitude value: (P8 & P9 control dynamics)		|
P5=Pitch									|
P6=pitch ramp: values other than 0 indicate ramp from P6 to P5 value		|
P7=amplitude ramp, in conjunction with P9					|
P8=amplitude peak: 0.1=decres., 0.9=cresc., 0.5=peak in middle of duration	|
P9=vibrato speed								|
======================================================
*/

;	INSTRUMENT 1
;||||||||||Gliss 1
f1 	0 1024 	 10 	16 0 3 0 2 0 1 0 .5

;	INSTRUMENT 2
;||||||||||Gliss 2
f2 	0 1024 	 10 	16 8 4 8 2 4 1 8

;	INSTRUMENT 3
;||||||||||Gliss 3
f3 	0 1024 	 10 	14 7 6 5 4 3 2 1
f4 	0 1024	 10   	1 .5 .333 .25 .2 .166 .142 .125 .111 .1 .09 .083 .076 .071 .066 .06

;	INSTRUMENTS 4 & 5
;||||||||||Flute Tables
f5  	0 8193  -9	1 2 0
f6  	0 8193  -9 	2 0.260 0 3 0.118 0 
f7  	0 8193  -9 	4 0.085 0 5 0.017 0 6 0.014 0 
f8  	0 8193  -9 	2 0.090 0 3 0.078 0 
f9  	0 8193  -9 	4 0.010 0 5 0.013 0 
f10	0 8193  -9 	2 0.029 0 3 0.011 0

;	INSTRUMENT 6
;||||||||||Bass Tables
f19	0 4096 	10	1
f20	0 4096 	10  	1 3 
f21	0 4096 5	1024 512 1
f22	0 4096 	10 	2 0 0 1 0 0 0 1
f23	0 4096 	10 	2 0 0 0 1 1 1 1 
f24	0 4096 	10	4 0 3 0 2 0 1 0

;VIBRATO
;	Start	Size	GEN
f25  	0   	1024    	10  	1
 
;==============
;VARIABLE TABLES
;==============

;++++ATTACK - Flutes
;	Start	Size	GEN	High	Table	Low 
;				Pitch 	Size	Pitch (shorter time for high pitch)
f26	0	257	-7	.2 	257 	.6

;++++ATTACK - Bass
;	Start	Size	GEN	High	Table	Low 
;				Pitch 	Size	Pitch
f27	0	257	-7	.1 	257 	.5
;====================
;++++DECAY - Flutes, Bass
;	Start	Size	GEN	High	Table	Low 
;				Pitch 	Size	Pitch
f28	0	257	-7	.05 	257 	.1
;====================
;++++HIGH PARTIALS TRIM	
;	Start	Size	GEN	Low	Table							High 
;				Pitch	Segment						Pitch
f31	0	513	-7	1000 	128	2000	128	3000	128	4500	129 	6000	;FLUTES
f32	0	513	-7	200   	128 	500	128	1000	128	1750	129	2500	;BASS
;====================
;++++BREATH NOISE - Flutes
;	Start	Size	GEN	Low	Table	High
;				Pitch	Size	Pitch
f29	0	129 	-7	.9 	129 	.5
;====================
;++++VIBRATO DEPTH - Flutes, Bass
;	Start	Table	GEN	Low	Table							High
;		Size		Pitch	Segment						Pitch
f30	0 	129 	-7 	.07 	32	.1	32	 .15	32	.25	33	.45

/* TEMPO = 100, Ritard at end */
t	0	100	159	100	161	76	161.75	25	163	17	164	10

;====================
;|||||||||| 3 Glissando Instruments
;====================

;Instr	Start	Dur	Rtime	Wet	Roll	Diff	harm1	harm2	att	rel			
i1	0	63	0.5	.4	2000	.5	1	4	.1	4
i1	.25	12.75	2.5	.5	2000	.5	4	1	.5	2
i1	3	36	0.5	.4	2000	.5	1	4	.1	4
i1	5.25	27.75	2.5	.5	2000	.5	4	1	.5	2
i1	38	54	0.5	.3	2000	.5	1	4	.1	5
i1	75.75	27.25	1.5	.4	2000	.3	4	1	.5	4
i1	143	9	0.5	.3	2000	.5	1	4	.1	5
i1	61	79.25	1.0	.4	2000	.3	4	1	.5	4

i2	1	162	0.5	.4	2000	.5	1	4	.1	4
i2	2	16	.	.5	2000	.5	4	1	.5	2
i2	34	19	.	.4	2000	.5	1	4	.1	4
i2	60	23	.	.5	2000	.5	4	1	.5	2
i2	80	43	.	.3	2000	.5	1	4	.1	5
i2	115	7	.	.5	2000	.3	4	1	.5	4
i2	123	19	.	.3	2000	.5	1	4	.1	5
i2	143	9	.	.5	2000	.3	4	1	.5	4

i3	3	160	2.5	.5	2000	.5	1	3	.3	5
i3	7	136	1.5	.3	2000	.5	3	1	.3	3
i3	83	40	1.0	.5	2000	.5	1	3	.3	5
i3	87	36	0.5	.3	2000	.5	3	1	.3	3

;=============
;|||||||||| INSTR 4	Flute 1
;=============
;p1	p2	p3	p4	p5	p6	p7	p8	p9	
;Instr   	Start	Dur	Amp	Pitch	Pitch	Amp	Peak	Vibrato
;==========================	From	Swell	Time	Speed
i4	0.52	0.41	50	9.09	0	2000	.35	0.5
i4	1.03	0.48	50	9.09	0	<	.	.				
i4	1.52	0.42	50	9.07	0	<	.	.				
i4	2.04	0.15	50	9.09	0	<	.	.				
i4	2.31	0.41	50	9.04	0	<	.	.				
i4	2.81	0.15	50	9.00	0	<	.	.				
i4	3.08	0.41	50	9.02	0	<	.	.				
i4	3.58	0.75	50	9.03	pp5	<	.7	2.5
i4	4.60	-0.23	20	8.09	0	<	.5	0.5				
i4	+	-0.15	20	9.00	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	-0.23	20	9.00	0	<	.	.				
i4	+	0.42	50	8.09	0	<	.35	.				
i4	6.13	0.50	50	9.00	0	<	.	.				
i4	6.64	0.42	50	8.09	0	<	.	.				
i4	7.17	0.41	50	8.07	0	<	.	.				
i4	7.68	0.41	50	8.09	0	<	.	.				
i4	8.70	0.41	50	9.00	0	<	.	.				
i4	9.20	0.50	50	9.00	0	<	.	.	
i4	9.72	0.41	50	9.02	0	<	.	.				
i4	10.23	-0.16	20	9.00	0	<	.5	.				
i4	+	-0.23	20	8.04	0	<	.	.				
i4	+	-0.23	20	8.07	0	<	.	.				
i4	+	0.15	50	8.09	0	<	.	.				
i4	11.25	0.42	50	8.07	0	<	.35	.				
i4	11.78	1.25	50	8.11	pp5	3375	.7	.				
i4	14.32	0.50	50	8.07	0	<	.35	.				
i4	14.84	0.41	50	8.04	0	<	.	.				
i4	15.35	0.42	50	8.02	0	<	.	.				
i4	15.86	0.42	50	8.04	0	<	.	.				
i4	17.40	0.49	50	9.04	0	<	.	.				
i4	17.91	0.42	50	8.11	0	<	.	.				
i4	18.42	0.75	50	8.09	0	<	.	2.5				
i4	19.45	0.41	50	8.11	0	<	.	0.5				
i4	19.96	1.26	50	8.07	0	<	.	3.0				
i4	22.52	0.75	50	8.04	0	<	.	2.5				
i4	23.54	0.42	50	8.11	0	<	.	0.5				
i4	24.07	0.41	50	8.09	0	<	.	.				
i4	25.07	-0.24	20	9.09	0	<	.5	.				
i4	+	0.15	50	9.07	0	<	.35	.				
i4	25.6	-0.23	20	9.09	0	<	.5	.				
i4	+	-0.23	20	10.00	0	<	.	.				
i4	+	-0.23	20	9.11	0	<	.	.				
i4	+	0.16	50	9.09	0	<	.35	.				
i4	26.62	-0.23	20	9.04	0	<	.5	.				
i4	+	-0.15	20	9.09	0	<	.	.				
i4	+	0.42	50	9.11	0	<	.35	.				
i4	27.65	0.41	50	9.02	0	<	.	.				
i4	28.16	0.57	50	9.03	pp5	<	.7	.				
i4	28.93	0.41	50	9.02	0	<	.35	.				
i4	29.44	0.15	50	9.00	0	<	.	.				
i4	29.69	0.41	50	8.11	0	<	.	.				
i4	30.20	0.41	50	8.09	0	<	.	.				
i4	30.72	0.41	50	8.11	0	<	.	.				
i4	31.24	0.74	50	8.07	0	<	.	2.5				
i4	32.26	0.41	50	8.09	0	<	.	0.5				
i4	33.28	-0.23	20	9.00	0	<	.5	.				
i4	+	0.15	50	8.11	0	<	.35	.				
i4	33.78	-0.24	20	9.00	0	<	.5	.				
i4	+	-0.23	20	9.04	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	0.15	50	9.00	0	<	.35	.				
i4	34.80	0.42	50	9.09	0	<	.	.				
i4	35.33	0.74	50	9.07	0	<	.	2.5				
i4	36.36	1.25	50	9.11	pp5	<	.7	3.0				
i4	38.90	0.50	50	9.07	0	<	.35	0.5				
i4	39.42	0.41	50	9.04	0	<	.	.				
i4	39.94	0.41	50	9.02	0	<	.	.				
i4	40.43	0.42	50	9.04	0	<	.	.				
i4	41.46	0.42	50	9.09	0	<	.	.				
i4	41.97	0.50	50	9.09	0	<	.	.				
i4	42.48	0.42	50	9.07	0	<	.	.				
i4	43.00	0.15	50	9.09	0	<	.	.				
i4	43.25	0.42	50	9.04	0	<	.	.				
i4	43.77	0.15	50	9.00	0	<	.	.				
i4	44.03	0.41	50	8.11	0	<	.	.				
i4	44.55	0.57	50	8.07	0	<	.	.				
i4	45.32	-0.23	20	9.07	0	<	.5	.				
i4	+	-0.23	20	9.05	0	<	.	.				
i4	+	0.14	50	9.04	0	<	.35	.				
i4	46.07	0.42	50	9.02	0	2025	.	.				
i4	46.6	0.41	50	9.00	0	<	.	.				
i4	47.10	0.41	50	9.02	0	<	.	.				
i4	47.62	0.74	50	8.11	0	<	.	2.5				
i4	48.64	0.41	50	9.00	0	<	.	0.5				
i4	49.66	0.75	50	9.04	0	<	.	2.5				
i4	50.67	0.75	50	9.02	0	<	.	.				
i4	51.71	0.75	50	9.00	0	<	.	.				
i4	52.72	-0.24	20	8.11	0	<	.5	0.5				
i4	+	0.15	50	9.00	0	<	.35	.				
i4	53.24	1.26	50	9.02	0	<	.	3.0				
i4	54.79	-0.23	20	8.09	0	<	.5	0.5				
i4	+	0.16	50	9.00	0	<	.35	.				
i4	55.29	-0.23	20	9.04	0	<	.5	.				
i4	+	0.16	50	9.09	0	<	.35	.				
i4	55.79	0.75	50	9.07	0	<	.	2.5				
i4	56.82	0.42	50	9.09	pp5	<	.7	0.5				
i4	57.86	0.41	50	9.09	0	<	.35	.				
i4	58.37	0.48	50	9.09	0	<	.	.				
i4	58.88	0.41	50	9.07	0	<	.	.				
i4	59.38	0.16	50	9.09	0	<	.	.				
i4	59.64	0.41	50	9.04	0	<	.	.				
i4	60.16	0.15	50	9.00	0	<	.	.				
i4	60.42	-0.23	20	9.02	0	<	.5	.				
i4	+	-0.23	20	9.03	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	0.14	50	9.00	0	<	.35	.				
i4	61.44	0.41	50	9.02	0	<	.	.				
i4	61.95	0.41	50	8.11	0	<	.	.				
i4	62.45	1.27	50	8.07	0	<	.	3.0				
i4	64.00	0.74	50	9.02	pp5	<	.7	2.5				
i4	65.03	0.41	50	9.04	0	<	.35	0.5				
i4	65.54	-0.23	20	9.09	0	<	.5	.				
i4	+	-0.24	20	9.11	0	<	.	.				
i4	+	-0.23	20	10.00	0	<	.	.				
i4	+	0.15	50	9.11	0	<	.35	.				
i4	66.56	0.41	50	9.09	0	<	.	.				
i4	67.08	0.74	50	9.07	0	<	.	2.5				
i4	68.08	0.75	50	9.04	0	<	.	.				
i4	69.12	0.41	50	9.03	0	<	.	0.5				
i4	69.64	0.74	50	8.11	pp5	<	.7	2.5				
i4	71.67	0.50	50	8.07	0	<	.35	0.5				
i4	72.19	0.41	50	8.04	0	<	.	.				
i4	72.69	0.42	50	8.02	0	<	.	.				
i4	73.21	0.41	50	8.04	0	<	.	.				
i4	74.24	0.41	50	9.09	0	6750	.	.				
i4	74.76	0.48	50	9.09	0	<	.	.				
i4	75.25	0.42	50	9.07	0	<	.	.				
i4	75.78	0.14	50	9.09	0	<	.	.				
i4	76.03	0.41	50	9.04	0	<	.	.				
i4	76.55	0.14	50	9.00	0	<	.	.				
i4	76.80	0.41	50	9.02	pp5	<	.7	.				
i4	77.32	0.74	50	9.03	0	<	.35	2.5				
i4	78.32	-0.24	20	8.09	0	<	.5	0.5				
i4	+	-0.15	20	9.00	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	-0.24	20	9.00	0	<	.	.				
i4	+	0.41	50	8.09	0	<	.35	.				
i4	79.86	0.50	50	9.00	0	<	.	0.5				
i4	80.39	0.41	50	8.09	0	<	.	.				
i4	80.90	0.41	50	8.07	0	<	.	.				
i4	81.39	0.42	50	8.09	0	<	.	.				
i4	82.42	0.42	50	9.00	0	<	.	.				
i4	82.93	0.50	50	9.00	0	<	.	0.5				
i4	83.46	0.41	50	9.02	0	<	.	.				
i4	83.95	-0.16	20	9.00	0	<	.5	.				
i4	+	-0.23	20	8.04	0	<	.	.				
i4	+	-0.23	20	8.07	0	<	.	.				
i4	+	0.14	50	8.09	0	<	.35	.				
i4	84.99	0.41	50	8.07	0	<	.	.				
i4	85.51	1.25	50	8.11	pp5	<	.7	3.0				
i4	88.06	0.49	50	8.07	0	<	.35	0.5				
i4	88.56	0.42	50	8.04	0	<	.	.				
i4	89.08	0.41	50	8.02	0	<	.	.				
i4	89.60	0.41	50	8.04	0	<	.	.				
i4	91.12	0.50	50	9.04	0	<	.	.				
i4	91.63	0.42	50	8.11	0	<	.	.				
i4	92.15	0.75	50	8.09	0	<	.	2.5				
i4	93.17	0.42	50	8.11	0	<	.	0.5				
i4	93.70	1.25	50	8.07	pp5	<	.7	3.0				
i4	96.24	0.75	50	8.04	0	<	.35	2.5				
i4	97.28	0.41	50	8.11	0	<	.	0.5				
i4	97.8	0.41	50	8.09	0	<	.	.				
i4	98.80	-0.24	20	9.09	0	<	.5	.				
i4	+	0.14	50	9.07	0	<	.35	.				
i4	99.31	-0.24	20	9.09	0	<	.5	.				
i4	+	-0.23	20	10.00	0	<	.	.				
i4	+	-0.24	20	9.11	0	<	.	.				
i4	+	0.16	50	9.09	0	<	.35	.				
i4	100.34	-0.24	20	9.04	0	<	.5	.				
i4	100.59	-0.16	20	9.09	0	<	.	.				
i4	+	0.41	50	9.11	0	<	.35	.				
i4	101.38	0.41	50	9.02	0	<	.	.				
i4	101.89	0.57	50	9.03	pp5	<	.7	.				
i4	102.66	0.41	50	9.02	0	<	.35	.				
i4	103.16	0.15	50	9.00	0	<	.	.				
i4	103.41	0.42	50	8.11	0	<	.	.				
i4	103.92	0.42	50	8.09	0	<	.	.				
i4	104.43	0.42	50	8.11	0	<	.	.				
i4	104.96	0.75	50	8.07	0	<	.	2.5				
i4	105.98	0.41	50	8.09	0	<	.	0.5				
i4	106.99	-0.24	20	9.00	0	<	.5	.				
i4	+	0.14	50	8.11	0	<	.35	.				
i4	107.52	-0.23	20	9.00	0	<	.5	.				
i4	+	-0.23	20	9.04	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	0.15	50	9.00	0	<	.35	.				
i4	108.55	0.41	50	9.09	0	<	.	.				
i4	109.06	0.74	50	9.07	0	<	.	2.5				
i4	110.08	1.25	50	9.11	pp5	<	.7	3.0				
i4	112.64	0.48	50	9.07	0	<	.35	0.5				
i4	113.16	0.41	50	9.04	0	<	.	.				
i4	113.65	0.42	50	9.02	0	<	.	.				
i4	114.17	0.41	50	9.04	0	<	.	.				
i4	115.19	0.42	50	9.09	0	<	.	.				
i4	115.70	0.50	50	9.09	0	<	.	.				
i4	116.23	0.41	50	9.07	0	<	.	.				
i4	116.74	0.14	50	9.09	0	<	.	.				
i4	117	0.41	50	9.04	0	<	.	.				
i4	117.49	0.16	50	9.00	0	<	.	.				
i4	117.76	0.41	50	8.11	0	<	.	.				
i4	118.28	0.57	50	8.07	0	<	.	.				
i4	119.04	-0.23	20	9.07	0	<	.5	.				
i4	+	-0.23	20	9.05	0	<	.5	.				
i4	+	0.16	50	9.04	0	<	.35	.				
i4	119.81	0.41	50	9.02	0	<	.	.				
i4	120.32	0.41	50	9.00	0	<	.	.				
i4	120.83	0.41	50	9.02	0	<	.	.				
i4	121.35	0.74	50	8.11	0	<	.	2.5				
i4	122.37	0.41	50	9.00	0	<	.	0.5				
i4	123.39	0.75	50	9.04	0	<	.	2.5				
i4	124.42	0.74	50	9.02	0	<	.	.				
i4	125.44	0.75	50	9.00	0	<	.	.				
i4	126.45	-0.24	20	8.11	0	<	.5	0.5				
i4	+	0.16	50	9.00	0	<	.35	.				
i4	126.97	1.26	50	9.02	0	<	.	3.0				
i4	128.50	-0.24	20	8.09	0	<	.5	0.5				
i4	+	0.14	50	9.00	0	<	.35	.				
i4	129.02	-0.23	20	9.04	0	<	.5	.				
i4	+	0.16	50	9.09	0	<	.35	.				
i4	129.54	0.74	50	9.07	0	<	.	2.5				
i4	130.56	0.41	50	9.09	pp5	<	.7	0.5				
i4	131.57	0.42	50	9.09	0	<	.35	.				
i4	132.10	0.48	50	9.09	0	<	.	.				
i4	132.59	0.42	50	9.07	0	<	.	.				
i4	133.12	0.15	50	9.09	0	<	.	.				
i4	133.38	0.41	50	9.04	0	<	.	.				
i4	133.89	0.14	50	9.00	0	<	.	.				
i4	134.13	-0.24	20	9.02	0	<	.5	.				
i4	+	-0.23	20	9.03	0	<	.	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	0.14	50	9.00	0	<	.35	.				
i4	135.16	0.41	50	9.02	0	<	.	.				
i4	135.67	0.42	50	8.11	0	<	.	.				
i4	136.2	1.25	50	8.07	0	<	.	3.0				
i4	137.72	0.75	50	9.02	0	<	.	2.5				
i4	138.75	0.41	50	9.04	0	<	.	0.5				
i4	139.26	-0.23	20	9.09	0	<	.5	.				
i4	+	-0.23	20	9.11	0	<	.	.				
i4	+	-0.23	20	10.00	0	<	.	.				
i4	+	0.16	50	9.11	0	<	.35	.				
i4	140.27	0.42	50	9.09	0	<	.	.				
i4	140.80	0.74	50	9.07	0	<	.	2.5				
i4	141.81	0.75	50	9.04	0	<	.	.				
i4	142.85	0.41	50	9.03	0	<	.	0.5				
i4	143.36	1.51	50	8.11	0	<	.	3.0				
i4	145.41	0.48	50	8.07	0	<	.	0.5				
i4	145.92	0.41	50	8.04	0	<	.	.				
i4	146.43	0.41	50	8.02	0	<	.	.				
i4	146.93	0.42	50	8.04	0	<	.	.				
i4	147.96	0.41	50	9.09	0	<	.	.				
i4	148.48	0.49	50	9.09	0	<	.	.				
i4	148.99	0.41	50	9.07	0	<	.	.				
i4	149.50	0.15	50	9.09	0	<	.	.				
i4	149.75	0.42	50	9.04	0	<	.	.				
i4	150.28	0.14	50	9.00	0	<	.	.				
i4	150.51	0.42	50	9.02	0	<	.	.				
i4	151.03	0.75	50	9.03	pp5	<	.7	2.5				
i4	152.05	-0.24	20	8.09	0	<	.35	0.5				
i4	+	-0.14	20	9.00	0	<	.5	.				
i4	+	-0.23	20	9.02	0	<	.	.				
i4	+	-0.23	20	9.00	0	<	.	.				
i4	+	0.41	50	8.09	0	<	.35	.				
i4	153.60	0.48	50	9.00	0	<	.	.	
i4	154.11	0.41	50	8.09	0	<	.	.				
i4	154.63	0.41	50	8.07	0	<	.	.				
i4	155.14	0.41	50	8.09	0	<	.	.				
i4	156.15	0.42	50	9.00	0	<	.	.				
i4	156.67	0.49	50	9.00	0	<	.	.				
i4	157.17	0.42	50	9.02	0	<	.	.				
i4	157.68	-0.16	20	9.00	0	<	.5	.				
i4	+	-0.23	20	8.04	0	<	.	.				
i4	+	-0.23	20	8.07	0	<	.	.				
i4	+	0.14	50	8.09	0	<	.35	.				
i4	158.72	0.41	50	8.07	0	<	.	.				
i4	159.24	1.25	50	8.11	pp5	1350	.7	3.0				
i4	161.78	-0.50	20	8.07	0	2700	.5	4.0				
i4	+	-0.41	20	8.04	pp5	2025	.7	4.5				
i4	+	-0.42	20	8.02	0	2025	.4	5.0				
i4	+	0.41	20	8.04	0	675	.1	6.0
				
;=============
;|||||||||| INSTR 5	Flute 2
;=============
;p1	p2	p3	p4	p5	p6	p7	p8	p9	
;Instr   	Start	Dur	Amp	Pitch	Pitch	Amp	Peak	Vibrato
;==========================	From	Swell	Time	Speed
i5	8.704	0.41	50	9.09	0	2000	.35	0.5				
i5	9.216	0.49	50	9.09	0	<	.	.				
i5	9.719	0.42	50	9.07	0	<	.	.				
i5	10.24	0.14	50	9.09	0	<	.	.				
i5	10.48	0.42	50	9.04	0	<	.	.				
i5	10.99	0.16	50	9.00	0	<	.	.				
i5	11.26	0.41	50	9.02	0	<	.	.				
i5	11.77	0.75	50	9.03	pp5	<	.7	2.5				
i5	12.79	-0.24	20	8.09	0	<	.5	0.5				
i5	+	-0.16	20	9.00	0	<	.	.				
i5	+	-0.24	20	9.02	0	<	.	.				
i5	+	-0.23	20	9.00	0	<	.	.				
i5	+	0.41	50	8.09	0	<	.35	.				
i5	14.33	0.49	50	9.00	0	<	.	.				
i5	14.85	0.41	50	8.09	0	<	.	.				
i5	15.36	0.41	50	8.07	0	<	.	.				
i5	15.88	0.41	50	8.09	0	<	.	.				
i5	16.89	0.41	50	9.00	0	<	.	.				
i5	17.41	0.48	50	9.00	0	<	.	.				
i5	17.92	0.41	50	9.02	0	<	.	.				
i5	18.42	-0.16	20	9.00	0	<	.5	.				
i5	+	-0.23	20	8.04	0	<	.	.				
i5	+	-0.23	20	8.07	0	<	.	.				
i5	+	0.15	50	8.09	0	<	.35	.				
i5	19.46	0.41	50	8.07	0	<	.	.				
i5	19.95	1.27	50	8.11	pp5	3375	.7	.				
i5	22.53	0.48	50	8.07	0	<	.35	.				
i5	23.04	0.41	50	8.04	0	<	.	.				
i5	23.55	0.41	50	8.02	0	<	.	.				
i5	24.06	0.41	50	8.04	0	<	.	.				
i5	25.60	0.48	50	9.04	0	<	.	.				
i5	26.10	0.42	50	8.11	0	<	.	.				
i5	26.61	0.75	50	8.09	0	<	.	2.5				
i5	27.63	0.42	50	8.11	0	<	.	0.5				
i5	28.16	1.26	50	8.07	0	<	.	3.0				
i5	30.72	0.74	50	8.04	0	<	.	2.5				
i5	31.75	0.41	50	8.11	0	<	.	0.5				
i5	32.26	0.41	50	8.09	0	<	.	.				
i5	33.28	-0.23	20	9.09	0	<	.5	.				
i5	+	0.15	50	9.07	0	<	.35	.				
i5	33.79	-0.23	20	9.09	0	<	.5	.				
i5	+	-0.23	20	10.00	0	<	.	.				
i5	+	-0.24	20	9.11	0	<	.	.				
i5	+	0.15	50	9.09	0	<	.35	.				
i5	34.81	-0.23	20	9.04	0	<	.5	.				
i5	+	-0.15	20	9.09	0	<	.	.				
i5	+	0.41	50	9.09	0	<	.35	.				
i5	35.84	0.41	50	9.02	0	<	.	.				
i5	36.36	0.57	50	9.03	pp5	<	.7	.				
i5	37.12	0.41	50	9.02	0	<	.35	.				
i5	37.62	0.16	50	9.00	0	<	.	.				
i5	37.87	0.42	50	8.11	0	<	.	.				
i5	38.39	0.42	50	8.09	0	<	.	.				
i5	38.92	0.41	50	8.11	0	<	.	.				
i5	39.43	0.74	50	8.07	0	<	.	2.5				
i5	40.44	0.41	50	8.09	0	<	.	0.5				
i5	41.47	-0.23	20	9.00	0	<	.5	.				
i5	+	0.16	50	8.11	0	<	.35	.				
i5	41.99	-0.23	20	9.00	0	<	.5	.				
i5	+	-0.24	20	9.04	0	<	.	.				
i5	+	-0.23	20	9.02	0	<	.	.				
i5	+	0.15	50	9.00	0	<	.35	.				
i5	43.00	0.41	50	9.09	0	<	.	.				
i5	43.52	0.74	50	9.07	0	<	.	2.5				
i5	44.53	1.27	50	9.11	pp5	<	.7	3.0				
i5	47.09	0.50	50	9.07	0	<	.35	0.5				
i5	47.60	0.42	50	9.04	0	<	.	.				
i5	48.11	0.42	50	9.02	0	<	.	.				
i5	48.64	0.41	50	9.04	0	<	.	.				
i5	49.65	0.42	50	9.09	0	<	.	.				
i5	50.18	0.48	50	9.09	0	<	.	.				
i5	50.67	0.42	50	9.07	0	<	.	.				
i5	51.2	0.15	50	9.09	0	<	.	.				
i5	51.44	0.42	50	9.04	0	<	.	.				
i5	51.97	0.14	50	9.00	0	<	.	.				
i5	52.23	0.41	50	8.11	0	<	.	.				
i5	52.72	0.58	50	8.07	0	<	.	.				
i5	53.51	-0.23	20	9.07	0	<	.5	.				
i5	+	-0.23	20	9.05	0	<	.	.				
i5	+	0.15	50	9.04	0	<	.35	.				
i5	54.27	0.41	50	9.02	0	2025	.	.				
i5	54.77	0.42	50	9.00	0	<	.	.				
i5	55.29	0.41	50	9.02	0	<	.	.				
i5	55.79	0.75	50	8.11	0	<	.	2.5				
i5	56.84	0.41	50	9.00	0	<	.	0.5				
i5	57.85	0.75	50	9.04	0	<	.	2.5				
i5	58.88	0.74	50	9.02	0	<	.	.				
i5	59.91	0.74	50	9.00	0	<	.	.				
i5	60.92	-0.23	20	8.11	0	<	.5	0.5				
i5	+	0.14	50	9.00	0	<	.35	.				
i5	61.44	1.25	50	9.02	0	<	.	3.0				
i5	62.97	-0.23	20	8.09	0	<	.5	0.5				
i5	+	0.15	50	9.00	0	<	.35	.				
i5	63.47	-0.24	20	9.04	0	<	.5	.				
i5	+	0.14	50	9.09	0	<	.35	.				
i5	63.99	0.75	50	9.07	0	<	.	2.5				
i5	65.01	0.42	50	9.09	0	<	.	0.5				
i5	66.05	0.41	50	9.09	0	<	.	.				
i5	66.55	0.50	50	9.09	0	<	.	.				
i5	67.06	0.42	50	9.07	0	<	.	.				
i5	67.58	0.15	50	9.09	0	<	.	.				
i5	67.83	0.42	50	9.04	0	<	.	.				
i5	68.35	0.15	50	9.00	0	<	.	.				
i5	68.60	-0.23	20	9.02	0	<	.5	.				
i5	+	-0.23	20	9.03	0	<	.	.				
i5	+	-0.23	20	9.02	0	<	.	.				
i5	+	0.15	50	9.00	0	<	.35	.				
i5	69.63	0.41	50	9.02	0	<	.	.				
i5	70.15	0.41	50	8.11	0	<	.	.				
i5	70.66	1.25	50	8.07	0	<	.	3.0				
i5	72.19	0.75	50	9.02	0	<	.	2.5				
i5	73.22	0.41	50	9.04	0	<	.	0.5				
i5	73.72	-0.23	20	9.09	0	<	.5	.				
i5	+	-0.23	20	9.11	0	<	.	.				
i5	+	-0.23	20	10.00	0	<	.	.				
i5	+	0.15	50	9.11	0	<	.35	.				
i5	74.74	0.42	50	9.09	0	<	.	.				
i5	75.25	0.75	50	9.07	0	<	.	2.5				
i5	76.27	0.75	50	9.04	0	<	.	.				
i5	77.31	0.41	50	9.03	0	<	.	0.5				
i5	77.82	0.75	50	8.11	0	<	.	2.5				
i5	79.86	0.50	50	8.07	0	<	.	0.5				
i5	80.37	0.42	50	8.04	0	<	.	.				
i5	80.89	0.41	50	8.02	0	<	.	.				
i5	81.41	0.41	50	8.04	0	<	.	.				
i5	82.44	0.41	50	9.09	0	<	.	.				
i5	82.94	0.49	50	9.09	0	6750	.	.				
i5	83.46	0.41	50	9.07	0	<	.	.				
i5	83.96	0.15	50	9.09	0	<	.	.				
i5	84.23	0.41	50	9.04	0	<	.	.				
i5	84.74	0.14	50	9.00	0	<	.	.				
i5	84.99	0.41	50	9.02	0	<	.	.				
i5	85.50	0.75	50	9.03	pp5	<	.7	2.5				
i5	86.51	-0.24	20	8.09	0	<	.5	0.5				
i5	+	-0.14	20	9.00	0	<	.	.				
i5	+	-0.23	20	9.02	0	<	.	.				
i5	+	-0.23	20	9.00	0	<	.	.				
i5	+	0.41	50	8.09	0	<	.35	.				
i5	88.06	0.49	50	9.00	0	<	.	.				
i5	88.58	0.41	50	8.09	0	<	.	.				
i5	89.09	0.41	50	8.07	0	<	.	.				
i5	89.6	0.41	50	8.09	0	<	.	.				
i5	90.61	0.42	50	9.00	0	<	.	.				
i5	91.12	0.50	50	9.02	0	<	.	.				
i5	91.64	0.41	50	9.02	0	<	.	.				
i5	92.15	-0.16	20	9.00	0	<	.5	.				
i5	+	-0.23	20	8.04	0	<	.	.				
i5	+	-0.23	20	8.07	0	<	.	.				
i5	+	0.14	50	8.09	0	<	.35	.				
i5	93.17	0.42	50	8.07	0	<	.	.				
i5	93.70	1.25	50	8.11	pp5	<	.7	3.0				
i5	96.25	0.49	50	8.07	0	<	.35	0.5				
i5	96.77	0.41	50	8.04	0	<	.	.				
i5	97.27	0.42	50	8.02	0	<	.	.				
i5	97.79	0.41	50	8.04	0	<	.	.				
i5	99.33	0.48	50	9.04	0	<	.	.				
i5	99.84	0.41	50	8.11	0	<	.	.				
i5	100.36	0.74	50	8.09	0	<	.	2.5				
i5	101.36	0.42	50	8.11	0	<	.	0.5
i5	101.89	1.25	50	8.07	pp5	<	.7	.				
i5	104.45	0.74	50	8.04	0	<	.35	2.5				
i5	105.48	0.41	50	8.11	0	<	.	0.5				
i5	105.99	0.41	50	8.09	0	<	.	.				
i5	107.01	-0.23	20	9.09	0	<	.5	.				
i5	+	0.15	50	9.07	0	<	.35	.				
i5	107.51	-0.24	20	9.09	0	<	.5	.				
i5	+	-0.23	20	10.00	0	<	.	.				
i5	+	-0.24	20	9.11	0	<	.	.				
i5	+	0.16	50	9.09	0	<	.35	.				
i5	108.55	-0.23	20	9.04	0	<	.	.				
i5	+	-0.14	20	9.09	0	<	.5	.				
i5	+	0.42	50	9.11	0	<	.35	.				
i5	109.57	0.41	50	9.02	0	<	.	.				
i5	110.08	0.58	50	9.03	pp5	<	.7	.				
i5	110.83	0.42	50	9.02	0	<	.35	.				
i5	111.36	0.14	50	9.00	0	<	.	.				
i5	111.62	0.41	50	8.11	0	<	.	.				
i5	112.11	0.42	50	8.09	0	<	.	.				
i5	112.63	0.42	50	8.11	0	<	.	.				
i5	113.15	0.75	50	8.07	0	<	.	2.5				
i5	114.17	0.41	50	8.09	0	<	.	0.5				
i5	115.20	-0.23	20	9.00	0	<	.5	.				
i5	+	0.16	50	8.11	0	<	.35	.				
i5	115.72	-0.23	20	9.00	0	<	.	.				
i5	+	-0.23	20	9.04	0	<	.5	.				
i5	+	-0.24	20	9.02	0	<	.	.				
i5	+	0.15	50	9.00	0	<	.35	.				
i5	116.74	0.41	50	9.09	0	<	.	.				
i5	117.23	0.75	50	9.07	0	<	.	2.5				
i5	118.26	1.27	50	9.11	pp5	<	.7	3.0				
i5	120.82	0.50	50	9.07	0	<	.35	0.5				
i5	121.35	0.41	50	9.04	0	<	.	.				
i5	121.86	0.41	50	9.02	0	<	.	.				
i5	122.36	0.41	50	9.04	0	<	.	.				
i5	123.39	0.41	50	9.09	0	<	.	.				
i5	123.91	0.48	50	9.09	0	<	.	.				
i5	124.40	0.42	50	9.07	0	<	.	.				
i5	124.92	0.15	50	9.09	0	<	.	.				
i5	125.17	0.42	50	9.04	0	<	.	.				
i5	125.68	0.16	50	9.00	0	<	.	.				
i5	125.96	0.41	50	8.11	0	<	.	.				
i5	126.45	0.58	50	8.07	0	<	.	.				
i5	127.22	-0.24	20	9.07	0	<	.5	.				
i5	+	-0.23	20	9.05	0	<	.	.				
i5	+	0.16	50	9.04	0	<	.35	.				
i5	127.99	0.42	50	9.02	0	<	.	.				
i5	128.50	0.42	50	9.00	0	<	.	.				
i5	129.02	0.41	50	9.02	0	<	.	.				
i5	129.53	0.75	50	8.11	0	<	.	2.5				
i5	130.56	0.41	50	9.00	0	<	.	0.5				
i5	131.58	0.75	50	9.04	0	<	.	2.5				
i5	132.60	0.75	50	9.02	0	<	.	.				
i5	133.62	0.75	50	9.00	0	<	.	.				
i5	134.65	-0.23	20	8.11	0	<	.5	0.5				
i5	+	0.14	50	9.00	0	<	.35	.				
i5	135.16	1.26	50	9.02	0	<	.	3.0				
i5	136.70	-0.23	20	8.09	0	<	.5	0.5				
i5	+	0.14	50	9.00	0	<	.35	.				
i5	137.21	-0.23	20	9.04	0	<	.5	.				
i5	+	0.15	50	9.09	0	<	.35	.				
i5	137.71	0.75	50	9.07	0	<	.	2.5				
i5	138.75	0.41	50	9.09	pp5	<	.7	0.5				
i5	139.77	0.41	50	9.09	0	<	.35	.				
i5	140.29	0.48	50	9.09	0	<	.	.				
i5	140.8	0.41	50	9.07	0	<	.	.				
i5	141.30	0.16	50	9.09	0	<	.	.				
i5	141.56	0.41	50	9.04	0	<	.	.				
i5	142.08	0.14	50	9.00	0	<	.	.				
i5	142.34	-0.23	20	9.02	0	<	.5	.				
i5	+	-0.23	20	9.03	0	<	.	.				
i5	+	-0.23	20	9.02	0	<	.	.				
i5	+	0.16	50	9.00	0	<	.35	.				
i5	143.36	0.41	50	9.02	0	<	.	.				
i5	143.87	0.41	50	8.11	0	<	.	.				
i5	144.39	1.25	50	8.07	0	<	.	3.0				
i5	145.92	0.74	50	9.02	0	<	.	2.5				
i5	146.95	0.41	50	9.04	0	<	.	0.5				
i5	147.46	-0.23	20	9.09	0	<	.5	.				
i5	+	-0.23	20	9.11	0	<	.	.				
i5	+	-0.23	20	10.00	0	<	.	.				
i5	+	0.15	50	9.11	0	<	.35	.				
i5	148.48	0.41	50	9.09	0	<	.	.				
i5	148.98	0.75	50	9.07	0	<	.	2.5				
i5	150.01	0.75	50	9.04	0	<	.	.				
i5	151.04	0.41	50	9.03	0	<	.	0.5				
i5	151.55	1.51	50	8.11	0	<	.	3.0				
i5	153.59	0.50	50	8.07	0	<	.	0.5				
i5	154.10	0.42	50	8.04	0	<	.	.				
i5	154.62	0.41	50	8.02	0	<	.	.				
i5	155.14	0.41	50	8.04	0	<	.	.				
i5	156.15	0.42	50	9.09	0	<	.	.				
i5	156.66	0.50	50	9.09	0	<	.	.				
i5	157.18	0.41	50	9.07	0	<	.	.				
i5	157.70	0.14	50	9.09	0	<	.	.				
i5	157.96	0.41	50	9.04	0	<	.	.				
i5	158.45	0.16	50	9.00	0	<	.	.				
i5	158.71	0.42	50	9.02	0	<	.	.				
i5	159.22	0.75	50	9.03	pp5	<	.7	2.5				
i5	160.25	-0.23	20	8.09	0	<	.	0.5				
i5	+	-0.16	20	9.00	0	<	.5	.				
i5	+	-0.23	20	9.02	0	<	.	.				
i5	+	-0.23	20	9.00	0	<	.	.				
i5	+	0.42	50	8.09	0	1350	.35	.				
i5	161.8	0.48	50	9.00	0	2700	.	4.0				
i5	+	-0.41	20	8.09	pp5	2025	.7	4.5				
i5	+	-0.41	20	8.07	0	2025	.5	5.0				
i5	+	0.42	20	8.09	0	675	.1	6.0				

;=============
;|||||||||| INSTR 6	Bass
;=============
;p1	p2	p3	p4	p5	p6	p7	p8	
;Instr   	Start	Dur	Amp	Pitch	Amp	Peak	Vibrato
;==========================	Swell	Time	Speed
i6	32.76	0.75	480	7.09	6500	.3	0.5
i6	32.76	.	.	6.09	.	.	.				
i6	33.78	.	.	7.09	.	.	.
i6	33.8	.	.	6.09	.	.	.				
i6	34.81	.	.	7.09	.	.	.
i6	34.81	.	.	6.09	.	.	.				
i6	35.84	0.41	.	7.09	.	.	.
i6	35.84	0.41	.	6.09	.	.	.		
i6	36.36	1.25	.	7.07	.	.	.
i6	36.36	.	.	6.07	.	.	.				
i6	37.87	0.75	.	7.07	.	.	.
i6	37.89	.	.	6.07	.	.	.				
i6	38.91	.	.	7.07	.	.	.
i6	38.92	.	.	6.07	.	.	.				
i6	39.92	0.41	.	7.07	.	.	.
i6	39.92	.	.	6.07	.	.	.				
i6	40.43	1.25	.	7.09	.	.	.
i6	40.44	.	.	6.09	.	.	.				
i6	41.97	0.75	.	7.09	.	.	.
i6	41.97	.	.	6.09	.	.	.				
i6	43.00	.	.	7.09	.	.	.
i6	43.01	.	.	6.09	.	.	.				
i6	44.02	0.41	.	7.09	.	.	.
i6	44.02	0.41	.	6.09	.	.	.				
i6	44.53	1.25	.	7.07	.	.	.
i6	44.54	.	.	6.07	.	.	.				
i6	46.08	0.75	.	7.07	.	.	.
i6	46.08	.	.	6.07	.	.	.				
i6	47.10	.	.	7.07	.	.	.
i6	47.10	.	.	6.07	.	.	.				
i6	48.11	0.41	.	7.07	.	.	.
i6	48.12	.	.	6.07	.	.	.				
i6	48.64	1.25	.	7.09	.	.	.
i6	48.64	.	.	6.09	.	.	.				
i6	50.16	0.75	.	7.09	.	.	.
i6	50.17	.	.	6.09	.	.	.				
i6	51.20	.	.	7.09	.	.	.
i6	51.20	.	.	6.09	.	.	.				
i6	52.21	0.41	.	7.09	.	.	.
i6	52.22	0.41	.	6.09	.	.	.				
i6	52.74	1.25	.	7.07	.	.	.
i6	52.74	.	.	6.07	.	.	.				
i6	54.28	0.75	.	7.07	.	.	.
i6	54.28	.	.	6.07	.	.	.				
i6	55.28	.	.	7.07	.	.	.
i6	55.29	.	.	6.07	.	.	.				
i6	56.31	0.41	.	7.07	.	.	.
i6	56.32	.	.	6.07	.	.	.				
i6	56.82	1.25	.	7.09	.	.	.
i6	56.84	.	.	6.09	.	.	.				
i6	58.37	0.75	.	7.09	.	.	.
i6	58.37	.	.	6.09	.	.	.				
i6	59.4	.	.	7.09	.	.	.
i6	59.4	.	.	6.09	.	.	.				
i6	60.41	0.41	.	7.09	.	.	.
i6	60.41	0.41	.	6.09	.	.	.				
i6	60.91	1.25	.	7.07	.	.	.
i6	60.91	.	.	6.07	.	.	.				
i6	62.45	0.75	.	7.07	.	.	.
i6	62.47	.	.	6.07	.	.	.				
i6	63.47	.	.	7.07	.	.	.
i6	63.48	.	.	6.07	.	.	.				
i6	64.50	0.41	.	7.07	.	.	.
i6	64.52	.	.	6.07	.	.	.				
i6	65.01	1.25	.	7.09	.	.	.
i6	65.03	.	.	6.09	.	.	.				
i6	66.55	0.75	.	7.09	.	.	.
i6	66.55	.	.	6.09	.	.	.				
i6	67.58	.	.	7.09	.	.	.
i6	67.59	.	.	6.09	.	.	.				
i6	68.61	0.41	.	7.09	.	.	.
i6	68.61	0.41	.	6.09	.	.	.				
i6	69.11	1.25	.	7.07	.	.	.
i6	69.12	.	.	6.07	.	.	.				
i6	70.65	0.75	.	7.07	.	.	.
i6	70.66	.	.	6.07	.	.	.				
i6	71.68	.	.	7.07	.	.	.
i6	71.68	.	.	6.07	.	.	.				
i6	72.69	0.41	.	7.07	.	.	.
i6	72.71	.	.	6.07	.	.	.				
i6	73.21	1.25	.	7.09	.	.	.
i6	73.21	.	.	6.09	.	.	.				
i6	74.75	0.75	.	7.09	.	.	.
i6	74.76	.	.	6.09	.	.	.				
i6	75.77	.	.	7.09	.	.	.
i6	75.77	.	.	6.09	.	.	.				
i6	76.79	0.41	.	7.09	.	.	.
i6	76.79	0.41	.	6.09	.	.	.				
i6	77.31	1.25	.	7.07	.	.	.
i6	77.32	.	.	6.07	.	.	.				
i6	78.84	0.75	.	7.07	.	.	.
i6	78.85	.	.	6.07	.	.	.				
i6	79.87	.	.	7.07	.	.	.
i6	79.88	.	.	6.07	.	.	.				
i6	80.88	0.41	.	7.07	.	.	.
i6	80.89	.	.	6.07	.	.	.				
i6	81.39	1.25	.	7.09	.	.	.
i6	81.40	.	.	6.09	.	.	.				
i6	82.94	0.75	.	7.09	.	.	.
i6	82.95	.	.	6.09	.	.	.				
i6	83.95	.	.	7.09	.	.	.
i6	83.97	.	.	6.09	.	.	.				
i6	84.98	0.41	.	7.09	.	.	.
i6	85.00	0.41	.	6.09	.	.	.				
i6	85.49	1.25	.	7.07	.	.	.
i6	85.51	.	.	6.07	.	.	.				
i6	87.03	0.75	.	7.07	.	.	.
i6	87.04	.	.	6.07	.	.	.				
i6	88.07	0.75	.	7.07	.	.	.
i6	88.07	.	.	6.07	.	.	.				
i6	89.07	0.41	.	7.07	.	.	.
i6	89.09	.	.	6.07	.	.	.				
i6	89.6	1.25	.	7.09	.	.	.
i6	89.60	.	.	6.09	.	.	.				
i6	91.12	0.75	.	7.09	.	.	.
i6	91.12	.	.	6.09	.	.	.				
i6	92.16	.	.	7.09	.	.	.
i6	92.16	.	.	6.09	.	.	.				
i6	93.17	0.41	.	7.09	.	.	.
i6	93.18	0.41	.	6.09	.	.	.				
i6	93.69	1.25	.	7.07	.	.	.
i6	93.70	.	.	6.07	.	.	.				
i6	95.22	0.75	.	7.07	.	.	.
i6	95.23	.	.	6.07	.	.	.				
i6	96.26	.	.	7.07	.	.	.
i6	96.26	.	.	6.07	.	.	.				
i6	97.28	0.41	.	7.07	.	.	.
i6	97.28	.	.	6.07	.	.	.				
i6	97.78	1.25	.	7.09	.	.	.
i6	97.79	.	.	6.09	.	.	.				
i6	99.31	0.75	.	7.09	.	.	.
i6	99.33	.	.	6.09	.	.	.				
i6	100.35	.	.	7.09	.	.	.
i6	100.35	.	.	6.09	.	.	.				
i6	101.36	0.41	.	7.09	.	.	.
i6	101.37	0.41	.	6.09	.	.	.				
i6	101.89	1.25	.	7.07	.	.	.
i6	101.89	.	.	6.07	.	.	.				
i6	103.42	0.75	.	7.07	.	.	.
i6	103.42	.	.	6.07	.	.	.				
i6	104.44	.	.	7.07	.	.	.
i6	104.44	.	.	6.07	.	.	.				
i6	105.46	0.41	.	7.07	.	.	.
i6	105.48	.	.	6.07	.	.	.				
i6	105.97	1.25	.	7.09	.	.	.
i6	105.98	.	.	6.09	.	.	.				
i6	107.51	0.75	.	7.09	.	.	.
i6	107.52	.	.	6.09	.	.	.				
i6	108.54	.	.	7.09	.	.	.
i6	108.55	.	.	6.09	.	.	.				
i6	109.55	0.41	.	7.09	.	.	.
i6	109.57	0.41	.	6.09	.	.	.				
i6	110.08	1.25	.	7.07	.	.	.
i6	110.08	.	.	6.07	.	.	.				
i6	111.61	0.75	.	7.07	.	.	.
i6	111.62	.	.	6.07	.	.	.				
i6	112.63	.	.	7.07	.	.	.
i6	112.64	.	.	6.07	.	.	.				
i6	113.65	0.41	.	7.07	.	.	.
i6	113.66	.	.	6.07	.	.	.				
i6	114.16	1.25	.	7.09	.	.	.
i6	114.17	.	.	6.09	.	.	.				
i6	115.71	0.75	.	7.09	.	.	.
i6	115.72	.	.	6.09	.	.	.				
i6	116.72	.	.	7.09	.	.	.
i6	116.73	.	.	6.09	.	.	.				
i6	117.75	0.41	.	7.09	.	.	.
i6	117.76	0.41	.	6.09	.	.	.				
i6	118.26	1.25	.	7.07	.	.	.
i6	118.28	.	.	6.07	.	.	.				
i6	119.79	0.75	.	7.07	.	.	.
i6	119.81	.	.	6.07	.	.	.				
i6	120.82	.	.	7.07	.	.	.
i6	120.83	.	.	6.07	.	.	.				
i6	121.84	0.41	.	7.07	.	.	.
i6	121.86	.	.	6.07	.	.	.				
i6	122.37	1.25	.	7.09	.	.	.
i6	122.37	.	.	6.09	.	.	.				
i6	123.90	0.75	.	7.09	.	.	.
i6	123.91	.	.	6.09	.	.	.				
i6	124.91	.	.	7.09	.	.	.
i6	124.91	.	.	6.09	.	.	.				
i6	125.94	0.41	.	7.09	.	.	.
i6	125.94	0.41	.	6.09	.	.	.				
i6	126.47	1.25	.	7.07	.	.	.
i6	126.47	.	.	6.07	.	.	.				
i6	127.99	0.75	.	7.07	.	.	.
i6	127.99	.	.	6.07	.	.	.				
i6	129.01	.	.	7.07	.	.	.
i6	129.02	.	.	6.07	.	.	.				
i6	130.03	0.41	.	7.07	.	.	.
i6	130.04	.	.	6.07	.	.	.				
i6	130.56	1.25	.	7.09	.	.	.
i6	130.56	.	.	6.09	.	.	.				
i6	132.08	0.75	.	7.09	.	.	.
i6	132.09	.	.	6.09	.	.	.				
i6	133.11	.	.	7.09	.	.	.
i6	133.12	.	.	6.09	.	.	.				
i6	134.13	0.41	.	7.09	.	.	.
i6	134.15	0.41	.	6.09	.	.	.				
i6	134.64	1.25	.	7.07	.	.	.
i6	134.65	.	.	6.07	.	.	.				
i6	136.19	0.75	.	7.07	.	.	.
i6	136.19	.	.	6.07	.	.	.				
i6	137.20	.	.	7.07	.	.	.
i6	137.21	.	.	6.07	.	.	.				
i6	138.24	0.41	.	7.07	.	.	.
i6	138.24	.	.	6.07	.	.	.				
i6	138.76	1.25	.	7.09	.	.	.
i6	138.76	.	.	6.09	.	.	.				
i6	140.27	0.75	.	7.09	.	.	.
i6	140.28	.	.	6.09	.	.	.				
i6	141.30	.	.	7.09	.	.	.
i6	141.32	.	.	6.09	.	.	.				
i6	142.33	0.41	.	7.09	.	.	.
i6	142.34	0.41	.	6.09	.	.	.				
i6	142.83	1.25	.	7.07	.	.	.
i6	142.84	.	.	6.07	.	.	.				
i6	144.37	0.75	.	7.07	.	.	.
i6	144.38	.	.	6.07	.	.	.				
i6	145.39	.	.	7.07	.	.	.
i6	145.41	.	.	6.07	.	.	.				
i6	146.42	0.41	.	7.07	.	.	.
i6	146.44	.	.	6.07	.	.	.				
i6	146.93	.	.	7.09	.	.	.
i6	146.95	.	.	6.09	.	.	.				

;		|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
;		5 BAND EQ INSTRUMENTS	
;		|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||

;======================================================
;INSTRUMENT 92								
;Flute 1		Lcut1	Lcut2		Hcut1	Hcut2			
f33  0  4  -2		300	1000		2500	5000							
										
;Instr	Sta	Dur    	Lgain1	Lgain2	Mgain	Hgain1	Hgain2	IN	OUT	
;p1	p2	p3	p4	p5	p6	p7	p8	p9	p10	
i92	0      	165      	.1        	.2       	.2      	.4        	.1        	4        	7
;======================================================

;======================================================
;INSTRUMENT 93								
;Flute 2		Lcut1	Lcut2		Hcut1	Hcut2			
f34  0  4  -2		300	1000		2500	5000							
										
;Instr	Sta	Dur    	Lgain1	Lgain2	Mgain	Hgain1	Hgain2	IN	OUT
;p1	p2	p3	p4	p5	p6	p7	p8	p9	p10	
i93	0      	165      	.2       	.3    	.2      	.5        	.1        	5        	8
;======================================================

;======================================================
;INSTRUMENT 94								
;Bass			Lcut1	Lcut2		Hcut1	Hcut2			
f35  0  4  -2		50	200		800	2000					
										
;Instr	Sta	Dur    	Lgain1	Lgain2	Mgain	Hgain1	Hgain2	IN	OUT	
;p1	p2	p3	p4	p5	p6	p7	p8	p9	p10	
i94	0      	165      	.2       	.2       	.3      	.2        	.1        	6        	9
;======================================================

;		||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
;		REVERB INSTRUMENTS	
;		||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||

;=================================================================================
;INSTRUMENT 97														
;REVERB 1		FL 1 	FL 2	FL 1	FL 2																	
;															
;instr	sta	dur	inL	inR	outL	outR	rvbL	rvbR	wetL	wetR	rollL	rollR	diffL	diffR	
;p1	p2	p3	p4	p5	p6	p7	p8	p9	p10	p11	p12	p13	p14	p15	
i97	0	165	7	8	10	11	0.4	0.4	.2	.2	2000	2000	.8	.8
;=================================================================================

;================================================
;INSTRUMENT 98							
;REVERB 2		Bass 	Bass												
;									
;instr	sta	dur	in	out	rvb	wet	roll	diff	
;p1	p2	p3	p4	p5	p6	p7	p8	p9	
i98	0	165	9	12	1.0	.3	1200	.5
;================================================

;		|||||||||||||||||||||||||||||||||||||||||||||||||
;		6 CHANNEL MIXER
;		|||||||||||||||||||||||||||||||||||||||||||||||||

;============================================================================
;INSTRUMENT 100												
;6 CHANNEL	Gliss 1     	Gliss 2      	Gliss 3              	Flute 1             	Flute 2     	Bass		
;MIXER	|CH 1		|CH 2		|CH 3           	|CH 4                 	|CH 5                	|CH 6   		  
;In/Gain/Pan	i      g		i      g		i        g  		i        g        p      i        g        p      i        g        p	        
;p1    p2  p3	p4   p5		p6   p7		p8     p9	p10   p11   p12  p13   p14   p15	p16   p17   p18 
;ins   sta dur    													
i100 0    165	1     .09		2    .09		3       .1        	10     .8      .35   11     .8    .65  	12     .5      .4
;============================================================================




</CsScore>

</CsoundSynthesizer>

